@@ -1,4 +1,5 @@
-from pervane import serve
+#from pervane import serve
+from pervane import run as serve
 import multiprocessing
 import gunicorn.app.base
 
@@ -31,5 +32,6 @@ def main(as_module=False):
   }
   StandaloneApplication(serve.app, options).run()
 
+
 if __name__ == '__main__':
   cli_main()
